.. _watchers_module:

:mod:`kazoo.recipe.watchers`
----------------------------

.. automodule:: kazoo.recipe.watchers

Public API
++++++++++

    .. autoclass:: DataWatch
        :members:

        .. automethod:: __init__

        .. automethod:: __call__


    .. autoclass:: ChildrenWatch
        :members:

        .. automethod:: __init__

        .. automethod:: __call__

    .. autoclass:: PatientChildrenWatch
        :members:

        .. automethod:: __init__
